@@ -3,7 +3,7 @@
 
 #include <antlr/config.hpp>
 #include "ncoParserTokenTypes.hpp"
-/* $ANTLR 2.7.7 (2006-11-01): "ncoGrammer.g" -> "ncoTree.hpp"$ */
+/* $ANTLR 2.7.7 (20130428): "ncoGrammer.g" -> "ncoTree.hpp"$ */
 #include <antlr/TreeParser.hpp>
 
 #line 1 "ncoGrammer.g"
@@ -160,21 +160,127 @@ vector<ast_lmt_sct> &ast_lmt_vtr)
      return nbr_dmn;
 } 
 
-int 
+bool
+lmt_var_mk(
+int nbr_dmn,
+RefAST lmt,
+NcapVector<lmt_sct*> &lmt_vtr ) 
+{
+	int idx;
+	int jdx;
+	int sz;   
+    int dmn_sz;     
+    ptr_unn op1;
+	var_sct *var;
+	std::string fnc_nm="lmt_var_mk"; 
+	
+	dbg_prn(fnc_nm,"start\n"); 
+	
+	// calculate variables
+	var=out(lmt->getFirstChild()->getFirstChild());
+	// convert result to type int
+	var=nco_var_cnf_typ(NC_UINT64,var);    
+	(void)cast_void_nctype((nc_type)NC_UINT64,&var->val);
+	sz=var->sz;
+	dmn_sz=var->sz / nbr_dmn;
+	
+    dbg_prn(fnc_nm,"step 1\n");   
+
+    // shape of var must be (nbr_dmn) or (nbr_dmn,2) or (nbr_dmn,3) 
+    if( dmn_sz * nbr_dmn != sz )
+	{
+	  var=nco_var_free(var);
+      return false;  
+    }
+
+    dbg_prn(fnc_nm,"step 2\n");   
+	
+    for(idx=0; idx<sz;idx+=dmn_sz)
+	 {
+
+		// fill out lmt structure
+		// use same logic as nco_lmt_prs 
+		lmt_sct* lmt_ptr=(lmt_sct*)nco_calloc((size_t)1,sizeof(lmt_sct));
+		lmt_ptr->nm=NULL;
+		//lmt_ptr->lmt_typ=-1;
+		lmt_ptr->is_usr_spc_lmt=True; /* True if any part of limit is user-specified, else False */
+		lmt_ptr->min_sng=NULL;
+		lmt_ptr->max_sng=NULL;
+		lmt_ptr->srd_sng=NULL;
+		lmt_ptr->is_usr_spc_min=False;
+		lmt_ptr->is_usr_spc_max=False;
+		/* rec_skp_ntl_spf is used for record dimension in multi-file operators */
+		lmt_ptr->rec_skp_ntl_spf=0L; /* Number of records skipped in initial superfluous files */
+
+       dbg_prn(fnc_nm,"step loop idx="+ nbr2sng(idx)+"\n");   
+	   
+       for(jdx=0;jdx<dmn_sz;jdx++)
+		{     
+		  dbg_prn(fnc_nm,"step loop jdx="+ nbr2sng(jdx)+"\n");   	
+		  
+         nco_uint64 uival= var->val.ui64p[idx+jdx];
+         switch(jdx){
+           case 0: 
+             lmt_ptr->is_usr_spc_min=True;
+             lmt_ptr->srt=uival;
+             break;
+           case 1: //end
+             lmt_ptr->is_usr_spc_max=True;
+             lmt_ptr->end=uival;
+             break;
+           case 2: //srd
+             lmt_ptr->srd_sng=strdup("~fill_in");
+             lmt_ptr->srd=uival;
+             break;			
+	       }
+
+		}
+		/* need to deal with situation where only start is defined -- ie picking only a single value */
+		if( lmt_ptr->is_usr_spc_min==True && lmt_ptr->is_usr_spc_max==False && lmt_ptr->srd_sng==NULL)
+		{
+			lmt_ptr->is_usr_spc_max=True;
+			lmt_ptr->end=lmt_ptr->srt; 
+       }    
+
+       lmt_vtr.push_back(lmt_ptr);		
+	}
+	 
+	cast_nctype_void((nc_type)NC_UINT64,&var->val);
+	var=nco_var_free(var);  
+	dbg_prn(fnc_nm,"end\n"); 
+	
+   return true;
+
+}
+
+
+
+bool 
 lmt_mk(
+int nbr_dmn,
 RefAST lmt,
 NcapVector<lmt_sct*> &lmt_vtr ) 
 {   
-int nbr_dmn;
+
 int idx;
 int jdx;
+int sz;
 lmt_sct *lmt_ptr;
 RefAST aRef;
-
 vector<ast_lmt_sct> ast_lmt_vtr;
 
+// deal with a single expression containing all indicies
+if(lmt->getNumberOfChildren()==1 && 
+   lmt->getFirstChild()->getNumberOfChildren()==1 &&
+   lmt->getFirstChild()->getFirstChild()->getType() != COLON)
+{
+   return lmt_var_mk(nbr_dmn,lmt,lmt_vtr);   ;            
+}
+
+
 // populate ast_lmt_vtr
-nbr_dmn=lmt_init(lmt,ast_lmt_vtr);
+if( nbr_dmn!=lmt_init(lmt,ast_lmt_vtr) )
+  return false;	
 
   for(idx=0 ; idx <nbr_dmn ; idx++){
 
@@ -235,7 +341,7 @@ nbr_dmn=lmt_init(lmt,ast_lmt_vtr);
     lmt_vtr.push_back(lmt_ptr);
   } // end idx
 
-   return nbr_dmn;
+   return true;;
 } /* end lmt_mk */
 
 /* Legacy run -- will remove soon
