@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnf_dmn.c,v 1.96 2014/12/31 01:50:07 zender Exp $ */
+/* $Header$ */
 
 /* Purpose: Conform dimensions between variables */
 
@@ -526,9 +526,8 @@ nco_var_dmn_rdr_mtd /* [fnc] Change dimension ordering of variable metadata */
   } /* end loop over dmn_rdr */
   
   /* Map permanent list of reversed dimensions to input variable */
-  for(dmn_shr_idx=0;dmn_shr_idx<dmn_shr_nbr;dmn_shr_idx++){
+  for(dmn_shr_idx=0;dmn_shr_idx<dmn_shr_nbr;dmn_shr_idx++)
     dmn_rvr_in[dmn_idx_shr_in[dmn_shr_idx]]=dmn_rvr_rdr[dmn_idx_shr_rdr[dmn_shr_idx]];
-  }
   
   /* No dimension re-ordering is necessary if dmn_in and dmn_rdr share fewer than two dimensions
      Dimension reversal must be done with even one shared dimension
@@ -569,9 +568,8 @@ nco_var_dmn_rdr_mtd /* [fnc] Change dimension ordering of variable metadata */
      Remember: dmn_in has dimension IDs relative to input file 
      Copy dmn_in->xrf to get dimension IDs relative to output file (once they are defined) 
      Oh come on, it only seems like cheating! */
-  for(dmn_out_idx=0;dmn_out_idx<dmn_out_nbr;dmn_out_idx++){
+  for(dmn_out_idx=0;dmn_out_idx<dmn_out_nbr;dmn_out_idx++)
     dmn_out[dmn_out_idx]=dmn_in[dmn_idx_out_in[dmn_out_idx]]->xrf;
-  }
   
   /* Re-ordered output dimension list dmn_out now comprises correctly ordered but 
      otherwise verbatim copies of dmn_out structures in calling routine */
@@ -792,7 +790,7 @@ nco_var_dmn_rdr_val /* [fnc] Change dimension ordering of variable values */
        Reversal maps element k to element N-1-k=N-k-1 
        Enhance speed by using that all elements along dimension share reversal */
     for(dmn_in_idx=0;dmn_in_idx<dmn_in_nbr;dmn_in_idx++)
-      if(dmn_rvr_in[dmn_in_idx]) dmn_in_sbs[dmn_in_idx]=var_in_cnt[dmn_in_idx]-dmn_in_sbs[dmn_in_idx]-1;
+      if(dmn_rvr_in[dmn_in_idx]) dmn_in_sbs[dmn_in_idx]=var_in_cnt[dmn_in_idx]-dmn_in_sbs[dmn_in_idx]-1L;
 
     /* Map variable's N-D array indices to get 1-D index into output data */
     var_out_lmn=0L;
