@@ -1250,7 +1250,36 @@ nco_scv_cnf_typ /* [fnc] Convert scalar attribute to typ_new using C implicit co
   scv_new.type=typ_new;
   *scv_old=scv_new;
   return True;
-} /* end nco_scv_cnf_typ */
+} /* end nco_scv_cnf_typ() */
+
+nco_bool /* O [flg] Input is integer type */
+nco_typ_ntg /* [fnc] Identify integer types */
+(const nc_type typ_in) /* I [enm] Type to check for integer-ness */
+{
+  nco_bool flg_ntg=True; /* CEWI */
+
+  switch(typ_in){
+  case NC_INT: 
+  case NC_SHORT: 
+  case NC_INT64: 
+  case NC_BYTE: 
+  case NC_UINT:
+  case NC_USHORT:
+  case NC_UINT64:
+  case NC_UBYTE: 
+    flg_ntg=True;
+    break;
+  case NC_FLOAT: 
+  case NC_DOUBLE: 
+  case NC_CHAR: 
+  case NC_NAT: 
+  case NC_STRING: 
+    flg_ntg=False;
+    break;
+  default: nco_dfl_case_nc_type_err(); break;
+  } /* end switch */
+  return flg_ntg;
+} /* end nco_typ_ntg() */
 
 nco_bool /* O [flg] Input is signed type */
 nco_typ_sgn /* [fnc] Identify signed types */
@@ -1279,7 +1308,7 @@ nco_typ_sgn /* [fnc] Identify signed types */
   default: nco_dfl_case_nc_type_err(); break;
   } /* end switch */
   return flg_sgn;
-} /* end nco_typ_sgn */
+} /* end nco_typ_sgn() */
 
 nco_bool /* O [flg] Input is netCDF3 atomic type */
 nco_typ_nc3 /* [fnc] Identify netCDF3 atomic types */
@@ -1308,7 +1337,7 @@ nco_typ_nc3 /* [fnc] Identify netCDF3 atomic types */
   default: nco_dfl_case_nc_type_err(); break;
   } /* end switch */
   return flg_nc3;
-} /* end nco_typ_nc3 */
+} /* end nco_typ_nc3() */
 
 nc_type /* O [enm] netCDF3 type */
 nco_typ_nc4_nc3 /* [fnc] Convert netCDF4 to netCDF3 atomic type */
@@ -1336,7 +1365,7 @@ nco_typ_nc4_nc3 /* [fnc] Convert netCDF4 to netCDF3 atomic type */
   default: nco_dfl_case_nc_type_err(); break;
   } /* end switch */
   return typ_nc4;
-} /* end nco_typ_nc4_nc3 */
+} /* end nco_typ_nc4_nc3() */
 
 nc_type /* O [enm] Return Highest type */
 ncap_typ_hgh /* [fnc] Return Highest type */
@@ -1417,7 +1446,7 @@ ncap_typ_hgh /* [fnc] Return Highest type */
   default: nco_dfl_case_nc_type_err(); break;
   } /* end switch */
   return typ_1;
-} /* end ncap_typ_hgh */
+} /* end ncap_typ_hgh() */
 
 nc_type /* O [enm] Higher precision of input variables */
 ncap_var_retype /* [fnc] Promote variable to higher common precision */
@@ -1434,7 +1463,7 @@ ncap_var_retype /* [fnc] Promote variable to higher common precision */
   if(var_2->type != typ_hgh) var_2=nco_var_cnf_typ(typ_hgh,var_2);
 
   return typ_hgh;
-} /* end ncap_var_retype */
+} /* end ncap_var_retype() */
 
 nc_type /* O [enm] Highest precision of arguments */
 ncap_scv_scv_cnf_typ_hgh_prc /* [fnc] Promote arguments to higher precision if necessary */
@@ -1452,7 +1481,7 @@ ncap_scv_scv_cnf_typ_hgh_prc /* [fnc] Promote arguments to higher precision if n
     (void)nco_scv_cnf_typ(scv_2->type,scv_1);
     return scv_2->type;
   } /* endif */
-} /* end ncap_scv_scv_cnf_typ_hgh_prc */
+} /* end ncap_scv_scv_cnf_typ_hgh_prc() */
 
 nc_type /* O [enm] Highest precision of arguments */
 ncap_var_scv_cnf_typ_hgh_prc /* [fnc] Promote arguments to higher precision if necessary */
